Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(869)

Unified Diff: components/safe_browsing_db/v4_local_database_manager.h

Issue 2626153003: [M56] Have a list of pending checks instead of pending clients (Closed)
Patch Set: Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/safe_browsing_db/v4_local_database_manager.h
diff --git a/components/safe_browsing_db/v4_local_database_manager.h b/components/safe_browsing_db/v4_local_database_manager.h
index 8c078880da0517abf6f6d1ce27c050675833ef85..c1e65141844d91a236eae8b2f520029a8cec4490 100644
--- a/components/safe_browsing_db/v4_local_database_manager.h
+++ b/components/safe_browsing_db/v4_local_database_manager.h
@@ -9,6 +9,7 @@
// and database that holds the downloaded updates.
#include <memory>
+#include <unordered_set>
#include "base/memory/weak_ptr.h"
#include "components/safe_browsing_db/database_manager.h"
@@ -162,9 +163,8 @@ class V4LocalDatabaseManager : public SafeBrowsingDatabaseManager {
FRIEND_TEST_ALL_PREFIXES(V4LocalDatabaseManagerTest,
TestGetSeverestThreatTypeAndMetadata);
- // The set of clients awaiting a full hash response. It is used for tracking
- // which clients have cancelled their outstanding request.
- typedef std::unordered_set<const Client*> PendingClients;
+ // The checks awaiting a full hash response from SafeBrowsing service.
+ typedef std::unordered_set<const PendingCheck*> PendingChecks;
// Called when all the stores managed by the database have been read from
// disk after startup and the database is ready for checking resource
@@ -271,9 +271,8 @@ class V4LocalDatabaseManager : public SafeBrowsingDatabaseManager {
// name of the file on disk that would contain the prefixes, if applicable.
ListInfos list_infos_;
- // The set of clients that are waiting for a full hash response from the
- // SafeBrowsing service.
- PendingClients pending_clients_;
+ // The checks awaiting for a full hash response from the SafeBrowsing service.
+ PendingChecks pending_checks_;
// The checks that need to be scheduled when the database becomes ready for
// use.
« no previous file with comments | « chrome/browser/loader/safe_browsing_resource_throttle.cc ('k') | components/safe_browsing_db/v4_local_database_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698